###################################################
### chunk number 1: Ex1 set options
###################################################
options(prompt = "R> ")


###################################################
### chunk number 2: Ex1 load package
###################################################
library("ModelMap")


###################################################
### chunk number 3: Ex1 Define model type
###################################################
model.type <- "RF"


###################################################
### chunk number 4: Ex1 Define training and test files
###################################################
qdatafn <- "VModelMapData.csv"
qdata.trainfn <- "VModelMapData_TRAIN.csv"
qdata.testfn  <- "VModelMapData_TEST.csv"


###################################################
### chunk number 5: Ex1 define folder
###################################################
folder <- getwd()


###################################################
### chunk number 6: Ex1 split training and test
###################################################
get.test(       proportion.test=0.2,
                qdatafn=qdatafn,
                seed=42,
                folder=folder,
                qdata.trainfn=qdata.trainfn,
                qdata.testfn=qdata.testfn)


###################################################
### chunk number 7: Ex1 Define model filenames
###################################################
MODELfn.a    <- "VModelMapEx1a"
MODELfn.b    <- "VModelMapEx1b"


###################################################
### chunk number 8: Ex1 Define predictors
###################################################
predList <- c(	"ELEV250",
								"EVI2005097","NDV2005097","NIR2005097","RED2005097"
								)
predFactor <- FALSE


###################################################
### chunk number 9: Ex1 Define response
###################################################
response.name.a <- "PINYON"
response.name.b <- "SAGE"
response.type <- "continuous"


###################################################
### chunk number 10: Ex1 set seed
###################################################
seed.a <- 38
seed.b <- 39


###################################################
### chunk number 11: Ex1 Define Identifier
###################################################
unique.rowname <- "ID"


###################################################
### chunk number 12: Ex1 Create Model
###################################################
model.obj.ex1a <- model.build( model.type=model.type,
                               qdata.trainfn=qdata.trainfn,
                               folder=folder,           
                               MODELfn=MODELfn.a,
                               predList=predList,
                               predFactor=predFactor,
                               response.name=response.name.a,
                               response.type=response.type,
                               seed=seed.a)
           
model.obj.ex1b <- model.build( model.type=model.type,
                               qdata.trainfn=qdata.trainfn,
                               folder=folder,           
                               MODELfn=MODELfn.b,
                               predList=predList,
                               predFactor=predFactor,
                               response.name=response.name.b,
                               response.type=response.type,
                               seed=seed.b)


###################################################
### chunk number 13: Ex1 Model Diagnostics
###################################################
model.pred.ex1a <- model.diagnostics( model.obj=model.obj.ex1a,
                                      qdata.testfn=qdata.testfn,
                                      folder=folder,           
                                      MODELfn=MODELfn.a,
                                      unique.rowname=unique.rowname,
                             # Model Validation Arguments
                  				            prediction.type="TEST",
                                      device.type=c("pdf"),
                                      cex=1.2)
           
model.pred.ex1b <- model.diagnostics( model.obj=model.obj.ex1b,
                                      qdata.testfn=qdata.testfn,
                                      folder=folder,           
                                      MODELfn=MODELfn.b,
                                      unique.rowname=unique.rowname,
                              # Model Validation Arguments
                                      prediction.type="TEST",
                                      device.type=c("pdf"),
                                      cex=1.2)


###################################################
### chunk number 14: ExElevReadGDAL
###################################################

elevfn <- paste(folder,"/VModelMapData_dem_ELEVM_250.img",sep="")
mapgrid <- readGDAL(elevfn,band=1)
mapgrid <- as.image.SpatialGridDataFrame(mapgrid)


###################################################
### chunk number 15: ExElev
###################################################

opar <- par(mar=c(4,4,3,6),xpd=NA,mgp=c(3, 2, .3))

col.ramp<-terrain.colors(101)

zlim <- c(1500,max(mapgrid$z,na.rm=TRUE))
legend.label<-rev(pretty(zlim,n=5))
legend.colors<-col.ramp[trunc((legend.label/max(legend.label))*100)+1]
legend.label<-paste(legend.label,"m",sep="")

legend.label<-paste((7:3)*500,"m")
legend.colors<-col.ramp[c(100,75,50,25,1)]

image(mapgrid, col = col.ramp,zlim=zlim,asp=1,bty="n")

legend(	x=max(mapgrid$x),y=max(mapgrid$y),
	    	legend=legend.label,
		    fill=legend.colors,
		    bty="n",
		    cex=1.2
)
mtext("Elevation of Study Region",side=3,line=1,cex=1.5)
par(opar)


###################################################
### chunk number 16: ExElevFig
###################################################

opar <- par(mar=c(4,4,3,6),xpd=NA,mgp=c(3, 2, .3))

col.ramp<-terrain.colors(101)

zlim <- c(1500,max(mapgrid$z,na.rm=TRUE))
legend.label<-rev(pretty(zlim,n=5))
legend.colors<-col.ramp[trunc((legend.label/max(legend.label))*100)+1]
legend.label<-paste(legend.label,"m",sep="")

legend.label<-paste((7:3)*500,"m")
legend.colors<-col.ramp[c(100,75,50,25,1)]

image(mapgrid, col = col.ramp,zlim=zlim,asp=1,bty="n")

legend(	x=max(mapgrid$x),y=max(mapgrid$y),
	    	legend=legend.label,
		    fill=legend.colors,
		    bty="n",
		    cex=1.2
)
mtext("Elevation of Study Region",side=3,line=1,cex=1.5)
par(opar)


###################################################
### chunk number 17: Ex1 update raster LUT
###################################################
rastLUTfn   <- "VModelMapData_LUT.csv"
rastLUTfn     <- read.table(rastLUTfn,header=FALSE,sep=",",stringsAsFactors=FALSE)
rastLUTfn[,1] <- paste(folder,rastLUTfn[,1],sep="/")


###################################################
### chunk number 18: Ex1 Define numrows
###################################################
numrows=500


###################################################
### chunk number 19: Ex1 Produce Maps
###################################################

model.mapmake( 	model.obj=model.obj.ex1a,
                folder=folder,           
                MODELfn=MODELfn.a,
                rastLUTfn=rastLUTfn,
             # Mapping arguments
                numrows=numrows,
                map.sd=TRUE)
            

model.mapmake( 	model.obj=model.obj.ex1b,
                folder=folder,           
                MODELfn=MODELfn.b,
                rastLUTfn=rastLUTfn,
             # Mapping arguments
                numrows=numrows,
                map.sd=TRUE)


###################################################
### chunk number 20: Ex1 define color sequence
###################################################
l <- seq(100,0,length.out=101)
c <- seq(0,100,length.out=101)
col.ramp <- hcl(h = 120, c = c, l = l)


###################################################
### chunk number 21: Ex1Map
###################################################
opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)

mapgrid.a <- read.asciigrid(paste(MODELfn.a,"_map.txt",sep=""),as.image=TRUE)
mapgrid.b <- read.asciigrid(paste(MODELfn.b,"_map.txt",sep=""),as.image=TRUE)

zlim <- c(0,max(mapgrid.a$z,mapgrid.b$z,na.rm=TRUE))
legend.label<-rev(pretty(zlim,n=5))
legend.colors<-col.ramp[trunc((legend.label/max(legend.label))*100)+1]
legend.label<-paste(legend.label,"%",sep="")

image(mapgrid.a, col = col.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.a,side=3,line=1,cex=1.2)
image(mapgrid.b, col = col.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.b,side=3,line=1,cex=1.2)

legend(	x=max(mapgrid.b$x),y=max(mapgrid.b$y),
	    	legend=legend.label,
		    fill=legend.colors,
		    bty="n",
		    cex=1.2
)
mtext("Percent Cover",side=3,line=1,cex=1.5,outer=T)
par(opar)


###################################################
### chunk number 22: Ex1MapFig
###################################################
opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)

mapgrid.a <- read.asciigrid(paste(MODELfn.a,"_map.txt",sep=""),as.image=TRUE)
mapgrid.b <- read.asciigrid(paste(MODELfn.b,"_map.txt",sep=""),as.image=TRUE)

zlim <- c(0,max(mapgrid.a$z,mapgrid.b$z,na.rm=TRUE))
legend.label<-rev(pretty(zlim,n=5))
legend.colors<-col.ramp[trunc((legend.label/max(legend.label))*100)+1]
legend.label<-paste(legend.label,"%",sep="")

image(mapgrid.a, col = col.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.a,side=3,line=1,cex=1.2)
image(mapgrid.b, col = col.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.b,side=3,line=1,cex=1.2)

legend(	x=max(mapgrid.b$x),y=max(mapgrid.b$y),
	    	legend=legend.label,
		    fill=legend.colors,
		    bty="n",
		    cex=1.2
)
mtext("Percent Cover",side=3,line=1,cex=1.5,outer=T)
par(opar)


###################################################
### chunk number 23: Ex1 define stdev color sequence
###################################################
stdev.ramp   <- hcl(h = 15, c = c, l = l)


###################################################
### chunk number 24: Ex1StdevMap
###################################################
opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)

mapgrid.a <- read.asciigrid(paste(MODELfn.a,"_stdev.txt",sep=""),as.image=TRUE)
mapgrid.b <- read.asciigrid(paste(MODELfn.b,"_stdev.txt",sep=""),as.image=TRUE)

zlim <- c(0,max(mapgrid.a$z,mapgrid.b$z,na.rm=TRUE))
legend.label<-rev(pretty(zlim,n=5))
legend.colors<-stdev.ramp[trunc((legend.label/max(legend.label))*100)+1]
legend.label<-paste(legend.label,"%",sep="")

image(mapgrid.a, col = stdev.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.a,side=3,line=1,cex=1.2)
image(mapgrid.b, col = stdev.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.b,side=3,line=1,cex=1.2)

legend(	x=max(mapgrid.b$x),y=max(mapgrid.b$y),
	    	legend=legend.label,
		    fill=legend.colors,
		    bty="n",
		    cex=1.2
)
mtext("Standard Deviation of Percent Cover",side=3,line=1,cex=1.5,outer=T)
par(opar)


###################################################
### chunk number 25: Ex1StdevMapFig
###################################################
opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)

mapgrid.a <- read.asciigrid(paste(MODELfn.a,"_stdev.txt",sep=""),as.image=TRUE)
mapgrid.b <- read.asciigrid(paste(MODELfn.b,"_stdev.txt",sep=""),as.image=TRUE)

zlim <- c(0,max(mapgrid.a$z,mapgrid.b$z,na.rm=TRUE))
legend.label<-rev(pretty(zlim,n=5))
legend.colors<-stdev.ramp[trunc((legend.label/max(legend.label))*100)+1]
legend.label<-paste(legend.label,"%",sep="")

image(mapgrid.a, col = stdev.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.a,side=3,line=1,cex=1.2)
image(mapgrid.b, col = stdev.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.b,side=3,line=1,cex=1.2)

legend(	x=max(mapgrid.b$x),y=max(mapgrid.b$y),
	    	legend=legend.label,
		    fill=legend.colors,
		    bty="n",
		    cex=1.2
)
mtext("Standard Deviation of Percent Cover",side=3,line=1,cex=1.5,outer=T)
par(opar)


###################################################
### chunk number 26: Ex1 define coefv color sequence
###################################################
coefv.ramp <- hcl(h = 70, c = c, l = l)


###################################################
### chunk number 27: Ex1CoefvMap
###################################################
opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)

mapgrid.a <- read.asciigrid(paste(MODELfn.a,"_coefv.txt",sep=""),as.image=TRUE)
mapgrid.b <- read.asciigrid(paste(MODELfn.b,"_coefv.txt",sep=""),as.image=TRUE)

zlim <- c(0,max(mapgrid.a$z,mapgrid.b$z,na.rm=TRUE))
legend.label<-rev(pretty(zlim,n=5))
legend.colors<-coefv.ramp[trunc((legend.label/max(legend.label))*100)+1]

image(mapgrid.a, col = coefv.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.a,side=3,line=1,cex=1.2)
image(mapgrid.b, col = coefv.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.b,side=3,line=1,cex=1.2)

legend(	x=max(mapgrid.b$x),y=max(mapgrid.b$y),
	    	legend=legend.label,
		    fill=legend.colors,
		    bty="n",
		    cex=1.2
)
mtext("Coefficient of Variation of Percent Cover",side=3,line=1,cex=1.5,outer=T)
par(opar)


###################################################
### chunk number 28: Ex1CoefvMapFig
###################################################
opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)

mapgrid.a <- read.asciigrid(paste(MODELfn.a,"_coefv.txt",sep=""),as.image=TRUE)
mapgrid.b <- read.asciigrid(paste(MODELfn.b,"_coefv.txt",sep=""),as.image=TRUE)

zlim <- c(0,max(mapgrid.a$z,mapgrid.b$z,na.rm=TRUE))
legend.label<-rev(pretty(zlim,n=5))
legend.colors<-coefv.ramp[trunc((legend.label/max(legend.label))*100)+1]

image(mapgrid.a, col = coefv.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.a,side=3,line=1,cex=1.2)
image(mapgrid.b, col = coefv.ramp,zlim=zlim,asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.b,side=3,line=1,cex=1.2)

legend(	x=max(mapgrid.b$x),y=max(mapgrid.b$y),
	    	legend=legend.label,
		    fill=legend.colors,
		    bty="n",
		    cex=1.2
)
mtext("Coefficient of Variation of Percent Cover",side=3,line=1,cex=1.5,outer=T)
par(opar)


###################################################
### chunk number 29: Ex2 Define model type
###################################################
model.type <- "RF"


###################################################
### chunk number 30: Ex2 Define training and test files
###################################################
qdatafn <- "VModelMapData.csv"


###################################################
### chunk number 31: Ex2 define folder
###################################################
folder <- getwd()


###################################################
### chunk number 32: Ex2 Define model filename
###################################################
MODELfn.a    <- "VModelMapEx2a"
MODELfn.b    <- "VModelMapEx2b"


###################################################
### chunk number 33: Ex2 Define predictors
###################################################
predList <- c(	"ELEV250","NLCD01_250",
								"EVI2005097","NDV2005097","NIR2005097","RED2005097"
								)
predFactor <- c("NLCD01_250")


###################################################
### chunk number 34: Ex2 Define response
###################################################
response.name.a <- "PINYON"
response.name.b <- "SAGE"
response.type <- "binary"


###################################################
### chunk number 35: Ex2 set seed
###################################################
seed.a <- 40
seed.b <- 41


###################################################
### chunk number 36: Ex2 Define Identifier
###################################################
unique.rowname <- "ID"


###################################################
### chunk number 37: Ex2 Define numrows
###################################################
numrows=500


###################################################
### chunk number 38: Ex2 update raster LUT
###################################################
rastLUTfn   <- "VModelMapData_LUT.csv"
rastLUTfn     <- read.table(rastLUTfn,header=FALSE,sep=",",stringsAsFactors=FALSE)
rastLUTfn[,1] <- paste(folder,rastLUTfn[,1],sep="/")


###################################################
### chunk number 39: Ex2 Create Model
###################################################
model.obj.ex2a <- model.build( model.type=model.type,
                               qdata.trainfn=qdatafn,
                               folder=folder,           
                               MODELfn=MODELfn.a,
                               predList=predList,
                               predFactor=predFactor,
                               response.name=response.name.a,
                               response.type=response.type,
                               seed=seed.a)
           
model.obj.ex2b <- model.build( model.type=model.type,
                               qdata.trainfn=qdatafn,
                               folder=folder,           
                               MODELfn=MODELfn.b,
                               predList=predList,
                               predFactor=predFactor,
                               response.name=response.name.b,
                               response.type=response.type,
                               seed=seed.b)


###################################################
### chunk number 40: Ex2 Model Diagnostics
###################################################
model.pred.ex2a <- model.diagnostics( model.obj=model.obj.ex2a,
                                      qdata.trainfn=qdatafn,
                                      folder=folder,           
                                      MODELfn=MODELfn.a,
                                      unique.rowname=unique.rowname,
                             # Model Validation Arguments
                  				            prediction.type="OOB",
                                      device.type=c("jpeg","pdf","postscript"),
                                      cex=1.2)
           
model.pred.ex2b <- model.diagnostics( model.obj=model.obj.ex2b,
                                      qdata.trainfn=qdatafn,
                                      folder=folder,           
                                      MODELfn=MODELfn.b,
                                      unique.rowname=unique.rowname,
                              # Model Validation Arguments
                                      prediction.type="OOB",
                                      device.type=c("jpeg","pdf","postscript"),
                                      cex=1.2)


###################################################
### chunk number 41: Ex2 Optimal Threshold Table
###################################################
opt.thresh.a <- read.table(paste(MODELfn.a,"_pred_optthresholds.csv",sep=""),header=TRUE,sep=",",stringsAsFactors=FALSE)
opt.thresh.a[,-1]<-signif(opt.thresh.a[,-1],2)

opt.thresh.b <- read.table(paste(MODELfn.b,"_pred_optthresholds.csv",sep=""),header=TRUE,sep=",",stringsAsFactors=FALSE)
opt.thresh.b[,-1]<-signif(opt.thresh.b[,-1],2)


pred.prev.a <- 
read.table(paste(MODELfn.a,"_pred_prevalence.csv",sep=""),header=TRUE,sep=",",stringsAsFactors=FALSE)
pred.prev.a[,-1]<-signif(pred.prev.a[,-1],2)

pred.prev.b <- 
read.table(paste(MODELfn.b,"_pred_prevalence.csv",sep=""),header=TRUE,sep=",",stringsAsFactors=FALSE)
pred.prev.b[,-1]<-signif(pred.prev.b[,-1],2)


###################################################
### chunk number 42: Ex2a Optimal Threshold Table Show
###################################################
opt.thresh.a


###################################################
### chunk number 43: Ex2b Optimal Threshold Table Show
###################################################
opt.thresh.b


###################################################
### chunk number 44: Ex2a Prevalence Table Show
###################################################
pred.prev.a


###################################################
### chunk number 45: Ex2b Prevalence Table Show
###################################################
pred.prev.b


###################################################
### chunk number 46: Ex2 Produce Maps
###################################################

model.mapmake( model.obj=model.obj.ex2a,
               folder=folder,           
               MODELfn=MODELfn.a,
               rastLUTfn=rastLUTfn,
          # Mapping arguments
               numrows=numrows,
               na.action = "na.omit")
            

model.mapmake(  model.obj=model.obj.ex2b,
                folder=folder,           
                MODELfn=MODELfn.b,
                rastLUTfn=rastLUTfn,
          # Mapping arguments
                numrows=numrows,
                na.action = "na.omit")


###################################################
### chunk number 47: Ex2 define color sequence
###################################################
h=c(	seq(10,30,length.out=10),
	    seq(31,40,length.out=10),
    	seq(41,90,length.out=60),
	    seq(91,100,length.out=10),
	    seq(101,110,length.out=10))
l =c(	seq(25,40,length.out=10),
	    seq(40,90,length.out=35),
	    seq(90,90,length.out=10),
	    seq(90,40,length.out=35),
	    seq(40,10,length.out=10))
probpres.ramp <- hcl(h = h, c = 80, l = l)


###################################################
### chunk number 48: Ex2ProbabilitySurface
###################################################
opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)

mapgrid.a <- read.asciigrid(paste(MODELfn.a,"_map.txt",sep=""),as.image=TRUE)
mapgrid.b <- read.asciigrid(paste(MODELfn.b,"_map.txt",sep=""),as.image=TRUE)

legend.subset<-c(100,80,60,40,20,1)
legend.colors<-probpres.ramp[legend.subset]
legend.label<-c("100%"," 80%"," 60%"," 40%"," 20%","  0%")

image(mapgrid.a, col = probpres.ramp,zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.a,side=3,line=1,cex=1.2)
image(mapgrid.b, col = probpres.ramp,zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.b,side=3,line=1,cex=1.2)

legend(	x=max(mapgrid.b$x),y=max(mapgrid.b$y),
		legend=legend.label,
		fill=legend.colors,
		bty="n",
		cex=1.2)
				    
mtext("Probability of Presence",side=3,line=1,cex=1.5,outer=T)
par(opar)


###################################################
### chunk number 49: Ex2ProductionMapsFig
###################################################
opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)

mapgrid.a <- read.asciigrid(paste(MODELfn.a,"_map.txt",sep=""),as.image=TRUE)
mapgrid.b <- read.asciigrid(paste(MODELfn.b,"_map.txt",sep=""),as.image=TRUE)

legend.subset<-c(100,80,60,40,20,1)
legend.colors<-probpres.ramp[legend.subset]
legend.label<-c("100%"," 80%"," 60%"," 40%"," 20%","  0%")

image(mapgrid.a, col = probpres.ramp,zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.a,side=3,line=1,cex=1.2)
image(mapgrid.b, col = probpres.ramp,zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.b,side=3,line=1,cex=1.2)

legend(	x=max(mapgrid.b$x),y=max(mapgrid.b$y),
		legend=legend.label,
		fill=legend.colors,
		bty="n",
		cex=1.2)
				    
mtext("Probability of Presence",side=3,line=1,cex=1.5,outer=T)
par(opar)


###################################################
### chunk number 50: Ex2aPresenceMaps
###################################################
opar <- par(mfrow=c(2,2),mar=c(2.5,3,4,1),oma=c(0,0,4,6),xpd=NA)
mapgrid <- read.asciigrid(paste(MODELfn.a,"_map.txt",sep=""),as.image=TRUE)
criteria <- c("Default","MaxKappa","ReqSens","ReqSpec")
criteria.labels<-c("Default","MaxKappa","ReqSens = 0.9","ReqSpec = 0.9")
for(i in 1:4){
	thresh<-opt.thresh.a$threshold[opt.thresh.a$opt.methods==criteria[i]]
	presencegrid<-mapgrid
	presencegrid$z <- ifelse(presencegrid$z>thresh,1,0)
	image(	presencegrid, col=c("white","forestgreen"),zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
	if(i==2){
		legend(	x=max(mapgrid$x),y=max(mapgrid$y),
						legend=c("Present","Absent"),
						fill=c("forestgreen","white"),
						bty="n",
						cex=1.2)}
	mtext(criteria.labels[i],side=3,line=2,cex=1.2)
	mtext(paste("threshold =",thresh),side=3,line=.5,cex=1)
}
mtext(MODELfn.a,side=3,line=0,cex=1.2,outer=TRUE)
mtext(response.name.a,side=3,line=2,cex=1.5,outer=TRUE)
par(opar)


###################################################
### chunk number 51: Ex2aPresenceMapsFig
###################################################
opar <- par(mfrow=c(2,2),mar=c(2.5,3,4,1),oma=c(0,0,4,6),xpd=NA)
mapgrid <- read.asciigrid(paste(MODELfn.a,"_map.txt",sep=""),as.image=TRUE)
criteria <- c("Default","MaxKappa","ReqSens","ReqSpec")
criteria.labels<-c("Default","MaxKappa","ReqSens = 0.9","ReqSpec = 0.9")
for(i in 1:4){
	thresh<-opt.thresh.a$threshold[opt.thresh.a$opt.methods==criteria[i]]
	presencegrid<-mapgrid
	presencegrid$z <- ifelse(presencegrid$z>thresh,1,0)
	image(	presencegrid, col=c("white","forestgreen"),zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
	if(i==2){
		legend(	x=max(mapgrid$x),y=max(mapgrid$y),
						legend=c("Present","Absent"),
						fill=c("forestgreen","white"),
						bty="n",
						cex=1.2)}
	mtext(criteria.labels[i],side=3,line=2,cex=1.2)
	mtext(paste("threshold =",thresh),side=3,line=.5,cex=1)
}
mtext(MODELfn.a,side=3,line=0,cex=1.2,outer=TRUE)
mtext(response.name.a,side=3,line=2,cex=1.5,outer=TRUE)
par(opar)


###################################################
### chunk number 52: Ex2bPresenceMaps
###################################################
opar <- par(mfrow=c(2,2),mar=c(2.5,3,4,1),oma=c(0,0,4,6),xpd=NA)
mapgrid <- read.asciigrid(paste(MODELfn.b,"_map.txt",sep=""),as.image=TRUE)
criteria <- c("Default","MaxKappa","ReqSens","ReqSpec")
criteria.labels<-c("Default","MaxKappa","ReqSens = 0.9","ReqSpec = 0.9")
for(i in 1:4){
	thresh<-opt.thresh.b$threshold[opt.thresh.b$opt.methods==criteria[i]]
	presencegrid<-mapgrid
	presencegrid$z <- ifelse(presencegrid$z>thresh,1,0)
	image(	presencegrid, col=c("white","forestgreen"),zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
	if(i==2){
		legend(	x=max(mapgrid$x),y=max(mapgrid$y),
						legend=c("Present","Absent"),
						fill=c("forestgreen","white"),
						bty="n",
						cex=1.2)}
	mtext(criteria.labels[i],side=3,line=2,cex=1.2)
	mtext(paste("threshold =",thresh),side=3,line=.5,cex=1)
}
mtext(MODELfn.b,side=3,line=0,cex=1.2,outer=TRUE)
mtext(response.name.b,side=3,line=2,cex=1.5,outer=TRUE)
par(opar)


###################################################
### chunk number 53: Ex2bPresenceMapsFig
###################################################
opar <- par(mfrow=c(2,2),mar=c(2.5,3,4,1),oma=c(0,0,4,6),xpd=NA)
mapgrid <- read.asciigrid(paste(MODELfn.b,"_map.txt",sep=""),as.image=TRUE)
criteria <- c("Default","MaxKappa","ReqSens","ReqSpec")
criteria.labels<-c("Default","MaxKappa","ReqSens = 0.9","ReqSpec = 0.9")
for(i in 1:4){
	thresh<-opt.thresh.b$threshold[opt.thresh.b$opt.methods==criteria[i]]
	presencegrid<-mapgrid
	presencegrid$z <- ifelse(presencegrid$z>thresh,1,0)
	image(	presencegrid, col=c("white","forestgreen"),zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
	if(i==2){
		legend(	x=max(mapgrid$x),y=max(mapgrid$y),
						legend=c("Present","Absent"),
						fill=c("forestgreen","white"),
						bty="n",
						cex=1.2)}
	mtext(criteria.labels[i],side=3,line=2,cex=1.2)
	mtext(paste("threshold =",thresh),side=3,line=.5,cex=1)
}
mtext(MODELfn.b,side=3,line=0,cex=1.2,outer=TRUE)
mtext(response.name.b,side=3,line=2,cex=1.5,outer=TRUE)
par(opar)


###################################################
### chunk number 54: Ex3 Define model type
###################################################
model.type <- "SGB"


###################################################
### chunk number 55: Ex3 Define training and test files
###################################################
qdatafn <- "VModelMapData.csv"


###################################################
### chunk number 56: Ex3 define folder
###################################################
folder <- getwd()


###################################################
### chunk number 57: Ex3 Define model filename
###################################################
MODELfn.a    <- "VModelMapEx3a"
MODELfn.b    <- "VModelMapEx3b"


###################################################
### chunk number 58: Ex3 Define predictors
###################################################
predList <- c(	"ELEV250","NLCD01_250",
								"EVI2005097","NDV2005097","NIR2005097","RED2005097"
								)
predFactor <- c("NLCD01_250")


###################################################
### chunk number 59: Ex3 Define response
###################################################
response.name.a <- "PINYON"
response.name.b <- "SAGE"
response.type <- "binary"


###################################################
### chunk number 60: Ex3 set seed
###################################################
seed.a <- 42
seed.b <- 43


###################################################
### chunk number 61: Ex3 Define Identifier
###################################################
unique.rowname <- "ID"


###################################################
### chunk number 62: Ex3 Define numrows
###################################################
numrows=500


###################################################
### chunk number 63: Ex3 update raster LUT
###################################################
rastLUTfn   <- "VModelMapData_LUT.csv"
rastLUTfn     <- read.table(rastLUTfn,header=FALSE,sep=",",stringsAsFactors=FALSE)
rastLUTfn[,1] <- paste(folder,rastLUTfn[,1],sep="/")


###################################################
### chunk number 64: Ex3 Create Model
###################################################
model.obj.ex3a <- model.build( model.type=model.type,
                               qdata.trainfn=qdatafn,
                               folder=folder,           
                               MODELfn=MODELfn.a,
                               predList=predList,
                               predFactor=predFactor,
                               response.name=response.name.a,
                               response.type=response.type,
                               seed=seed.a)
           
model.obj.ex3b <- model.build( model.type=model.type,
                               qdata.trainfn=qdatafn,
                               folder=folder,           
                               MODELfn=MODELfn.b,
                               predList=predList,
                               predFactor=predFactor,
                               response.name=response.name.b,
                               response.type=response.type,
                               seed=seed.b)


###################################################
### chunk number 65: Ex3 Model Diagnostics
###################################################
model.pred.ex3a <- model.diagnostics( model.obj=model.obj.ex3a,
                                      qdata.trainfn=qdatafn,
                                      folder=folder,           
                                      MODELfn=MODELfn.a,
                                      unique.rowname=unique.rowname,
                                      seed=44,
                             # Model Validation Arguments
                  				            prediction.type="CV",
                                      device.type=c("jpeg","pdf","postscript"),
                                      cex=1.2,
                                      na.action = "na.roughfix")
           
model.pred.ex3b <- model.diagnostics( model.obj=model.obj.ex3b,
                                      qdata.trainfn=qdatafn,
                                      folder=folder,           
                                      MODELfn=MODELfn.b,
                                      unique.rowname=unique.rowname,
                                      seed=45,
                              # Model Validation Arguments
                                      prediction.type="CV",
                                      device.type=c("jpeg","pdf","postscript"),
                                      cex=1.2,
                                      na.action = "na.roughfix")


###################################################
### chunk number 66: Ex3 Optimal Threshold Table
###################################################
opt.thresh.a <- read.table(paste(MODELfn.a,"_pred_optthresholds.csv",sep=""),header=TRUE,sep=",",stringsAsFactors=FALSE)
opt.thresh.a[,-1]<-signif(opt.thresh.a[,-1],2)

opt.thresh.b <- read.table(paste(MODELfn.b,"_pred_optthresholds.csv",sep=""),header=TRUE,sep=",",stringsAsFactors=FALSE)
opt.thresh.b[,-1]<-signif(opt.thresh.b[,-1],2)


###################################################
### chunk number 67: Ex3a Optimal Threshold Table Show
###################################################
opt.thresh.a


###################################################
### chunk number 68: Ex3b Optimal Threshold Table Show
###################################################
opt.thresh.b


###################################################
### chunk number 69: Ex3 Produce Maps
###################################################

model.mapmake( model.obj=model.obj.ex3a,
               folder=folder,           
               MODELfn=MODELfn.a,
               rastLUTfn=rastLUTfn,
          # Mapping arguments
               map=TRUE,
               numrows=numrows,
               na.action = "na.roughfix")
            

model.mapmake( model.obj=model.obj.ex3b,
               folder=folder,           
               MODELfn=MODELfn.b,
               rastLUTfn=rastLUTfn,
          # Mapping arguments
               map=TRUE,
               numrows=numrows,
               na.action = "na.roughfix")


###################################################
### chunk number 70: Ex3 define color sequence
###################################################
h=c(	seq(10,30,length.out=10),
	    seq(31,40,length.out=10),
    	seq(41,90,length.out=60),
	    seq(91,100,length.out=10),
	    seq(101,110,length.out=10))
l =c(	seq(25,40,length.out=10),
	    seq(40,90,length.out=35),
	    seq(90,90,length.out=10),
	    seq(90,40,length.out=35),
	    seq(40,10,length.out=10))
probpres.ramp <- hcl(h = h, c = 80, l = l)


###################################################
### chunk number 71: Ex3ProbabilitySurface
###################################################
opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)

mapgrid.a <- read.asciigrid(paste(MODELfn.a,"_map.txt",sep=""),as.image=TRUE)
mapgrid.b <- read.asciigrid(paste(MODELfn.b,"_map.txt",sep=""),as.image=TRUE)

legend.subset<-c(100,80,60,40,20,1)
legend.colors<-probpres.ramp[legend.subset]
legend.label<-c("100%"," 80%"," 60%"," 40%"," 20%","  0%")

image(mapgrid.a, col = probpres.ramp,zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.a,side=3,line=1,cex=1.2)
image(mapgrid.b, col = probpres.ramp,zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.b,side=3,line=1,cex=1.2)

legend(	x=max(mapgrid.b$x),y=max(mapgrid.b$y),
		legend=legend.label,
		fill=legend.colors,
		bty="n",
		cex=1.2)
				    
mtext("Probability of Presence",side=3,line=1,cex=1.5,outer=T)
par(opar)


###################################################
### chunk number 72: Ex3ProductionMapsFig
###################################################
opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)

mapgrid.a <- read.asciigrid(paste(MODELfn.a,"_map.txt",sep=""),as.image=TRUE)
mapgrid.b <- read.asciigrid(paste(MODELfn.b,"_map.txt",sep=""),as.image=TRUE)

legend.subset<-c(100,80,60,40,20,1)
legend.colors<-probpres.ramp[legend.subset]
legend.label<-c("100%"," 80%"," 60%"," 40%"," 20%","  0%")

image(mapgrid.a, col = probpres.ramp,zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.a,side=3,line=1,cex=1.2)
image(mapgrid.b, col = probpres.ramp,zlim=c(0,1),asp=1,bty="n",xaxt="n",yaxt="n")
mtext(response.name.b,side=3,line=1,cex=1.2)

legend(	x=max(mapgrid.b$x),y=max(mapgrid.b$y),
		legend=legend.label,
		fill=legend.colors,
		bty="n",
		cex=1.2)
				    
mtext("Probability of Presence",side=3,line=1,cex=1.5,outer=T)
par(opar)


